Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ConfigFile string
ConfigFile contains the path to the config file on disk
var DryRun bool
Flag to show that the user wants a dry run
var Force bool
Flag to show that the user wants to force certificate update
var QuietLogging bool
Flag to show that the user wants quiet logging
var VerboseLogging bool
Flag to show that the user wants verbose logging
Functions ¶
This section is empty.
Types ¶
type CertificateData ¶
type CertificateData struct {
Name string `yaml:"name"`
CertificateSecret string `yaml:"cert_secret"`
CertificatePath string `yaml:"cert_path"`
KeySecret string `yaml:"key_secret"`
KeyPath string `yaml:"key_path"`
CaPath string `yaml:"ca_path"`
Action string `yaml:"action"`
}
Struct that holds the details of a single managed certificate
type ConfigFileData ¶
type ConfigFileData struct {
BaseURL string `yaml:"base_url"`
DisableCertificateValidation bool `yaml:"disable_certificate_validation"`
Certificates []CertificateData `yaml:"certificates"`
}
Struct to read the config file into when reading from disk
var Config *ConfigFileData
Config file gets read into here
func InitializeConfig ¶
func InitializeConfig() (*ConfigFileData, error)
func (*ConfigFileData) IsValid ¶
func (c *ConfigFileData) IsValid() ConfigValidationError
IsValid tests if the config read from file has all required parameters set.
Exits the app if errors are detected
func (*ConfigFileData) SubstituteKeys ¶
func (c *ConfigFileData) SubstituteKeys(logger *slog.Logger)
type ConfigValidationError ¶
type ConfigValidationError struct {
ErrorMessages []string
}
func (*ConfigValidationError) Add ¶
func (e *ConfigValidationError) Add(msg string)
func (*ConfigValidationError) Error ¶
func (e *ConfigValidationError) Error() string
func (*ConfigValidationError) HasMessages ¶
func (e *ConfigValidationError) HasMessages() bool
func (*ConfigValidationError) Print ¶
func (e *ConfigValidationError) Print(logger *slog.Logger)
Click to show internal directories.
Click to hide internal directories.